powered by
Measurement of Spatial Stratified Heterogeneity Based on Information Consistency for Continuous Variables
sshic(d, s, seed = 42, permutation_number = 999, bin_method = "Sturges")
A two-element numerical vector.
The target variable.
The stratification.
(optional) Random number seed, default is 42.
42
(optional) Number of Random Permutations, default is 999.
999
(optional) Histogram binning method for probability density estimation, default is Sturges.
Sturges
# \donttest{ # This code may take a bit longer to execute: baltim = sf::read_sf(system.file("extdata/baltim.gpkg",package = "sshicm")) sshic(baltim$PRICE,baltim$DWELL) # }
Run the code above in your browser using DataLab