Learn R Programming

sshicm (version 0.1.0)

sshin: Measurement of Spatial Stratified Heterogeneity Based on Information Consistency for Nominal Variables

Description

Measurement of Spatial Stratified Heterogeneity Based on Information Consistency for Nominal Variables

Usage

sshin(d, s, seed = 42, permutation_number = 999)

Value

A two-element numerical vector.

Arguments

d

The target variable.

s

The stratification.

seed

(optional) Random number seed, default is 42.

permutation_number

(optional) Number of Random Permutations, default is 999.

Examples

Run this code
# \donttest{
# This code may take a bit longer to execute:
cinc = sf::read_sf(system.file("extdata/cinc.gpkg",package = "sshicm"))
sshin(cinc$THEFT_D,cinc$MALE)
# }

Run the code above in your browser using DataLab