powered by
Measurement of Spatial Stratified Heterogeneity Based on Information Consistency for Nominal Variables
sshin(d, s, seed = 42, permutation_number = 999)
A two-element numerical vector.
The target variable.
The stratification.
(optional) Random number seed, default is 42.
42
(optional) Number of Random Permutations, default is 999.
999
# \donttest{ # This code may take a bit longer to execute: cinc = sf::read_sf(system.file("extdata/cinc.gpkg",package = "sshicm")) sshin(cinc$THEFT_D,cinc$MALE) # }
Run the code above in your browser using DataLab